@@ -67,7 +67,9 @@ struct _GkrLocationManagerPrivate;
 typedef struct _GkrLocationManagerPrivate GkrLocationManagerPrivate;
 
 struct _GkrLocationManagerPrivate {
+#ifdef WITH_HAL
 	LibHalContext *hal_ctx;
+#endif
 	GHashTable *volumes_by_name;
 	GHashTable *volumes_by_loc;
 	GHashTable *volumes_by_prefix;
@@ -402,7 +404,10 @@ static void
 gkr_location_manager_init (GkrLocationManager *locmgr)
 {
 	GkrLocationManagerPrivate *pv = GKR_LOCATION_MANAGER_GET_PRIVATE (locmgr);
-	const gchar *home, *env;
+	const gchar *home;
+#ifdef WITH_TESTS
+	const gchar *env;
+#endif
 	gchar *local = NULL;
 
 	pv->volumes_by_name = g_hash_table_new_full (g_str_hash, g_str_equal, 
@@ -439,9 +444,8 @@ gkr_location_manager_init (GkrLocationManager *locmgr)
 static void 
 gkr_location_manager_dispose (GObject *obj)
 {
-	GkrLocationManager *locmgr = GKR_LOCATION_MANAGER (obj);
-
 #ifdef WITH_HAL
+	GkrLocationManager *locmgr = GKR_LOCATION_MANAGER (obj);
 	location_manager_hal_uninit (locmgr);
 #endif	
 	
